TimelineDots class

Constructors

TimelineDots({required BuildContext context})
TimelineDots.of(BuildContext context)
factory

Properties

borderDot → Widget
no setter
circleIcon → Widget
no setter
context ↔ BuildContext
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
section → Widget
no setter
sectionHighlighted → Widget
no setter
simple → Widget
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited